@@ -1,19 +1,19 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
+* Licensed to the Apache Software Foundation (ASF) under one or more
+* contributor license agreements.  See the NOTICE file distributed with
+* this work for additional information regarding copyright ownership.
+* The ASF licenses this file to You under the Apache License, Version 2.0
+* (the "License"); you may not use this file except in compliance with
+* the License.  You may obtain a copy of the License at
+*
+*     http://www.apache.org/licenses/LICENSE-2.0
+*
+* Unless required by applicable law or agreed to in writing, software
+* distributed under the License is distributed on an "AS IS" BASIS,
+* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+* See the License for the specific language governing permissions and
+* limitations under the License.
+*/
 package compressionFilters;
 
 import java.io.IOException;
@@ -23,9 +23,8 @@ import java.util.Enumeration;
 import java.util.List;
 import java.util.StringTokenizer;
 
-import javax.servlet.Filter;
 import javax.servlet.FilterChain;
-import javax.servlet.FilterConfig;
+import javax.servlet.GenericFilter;
 import javax.servlet.ServletException;
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletResponse;
@@ -39,7 +38,9 @@ import javax.servlet.http.HttpServletResponse;
  * @author Amy Roh
  * @author Dmitri Valdin
  */
-public class CompressionFilter implements Filter {
+public class CompressionFilter extends GenericFilter {
+
+    private static final long serialVersionUID = 1L;
 
     /**
      * Minimal reasonable threshold.
@@ -72,21 +73,14 @@ public class CompressionFilter implements Filter {
      */
     private int debug = 0;
 
-    /**
-     * Place this filter into service.
-     *
-     * @param filterConfig The filter configuration object
-     */
     @Override
-    public void init(FilterConfig filterConfig) {
-
-        if (filterConfig != null) {
-            String value = filterConfig.getInitParameter("debug");
-            if (value!=null) {
-                debug = Integer.parseInt(value);
+    public void init() {
+        String str = getInitParameter("debug");
+        if (str != null) {
+            debug = Integer.parseInt(str);
         }
 
-            String str = filterConfig.getInitParameter("compressionThreshold");
+        str = getInitParameter("compressionThreshold");
         if (str != null) {
             compressionThreshold = Integer.parseInt(str);
             if (compressionThreshold != 0 && compressionThreshold < MIN_THRESHOLD) {
@@ -98,7 +92,7 @@ public class CompressionFilter implements Filter {
             }
         }
 
-            str = filterConfig.getInitParameter("compressionBuffer");
+        str = getInitParameter("compressionBuffer");
         if (str != null) {
             compressionBuffer = Integer.parseInt(str);
             if (compressionBuffer < MIN_BUFFER) {
@@ -110,7 +104,7 @@ public class CompressionFilter implements Filter {
             }
         }
 
-            str = filterConfig.getInitParameter("compressionMimeTypes");
+        str = getInitParameter("compressionMimeTypes");
         if (str != null) {
             List<String> values = new ArrayList<>();
             StringTokenizer st = new StringTokenizer(str, ",");
@@ -135,15 +129,6 @@ public class CompressionFilter implements Filter {
         }
     }
 
-    }
-
-    /**
-    * Take this filter out of service.
-    */
-    @Override
-    public void destroy() {
-    }
-
     /**
      * The <code>doFilter</code> method of the Filter is called by the container
      * each time a request/response pair is passed through the chain due
